% Constructor of the finite element block class for linear acoustics.
%
% function retobj = feblock_acoustics (varargin)
%
%    This class implements the linear acoustics operations.
%
% See discussion of constructors in <a href="matlab:helpwin 'FAESOR/classes/Contents'">classes/Contents</a>. 
% Options: those recognized by feblock, plus
% N = Outer normal, either as an array of numbers,or as a function handle.
%     Signature as in this example (tangent is in matrix with tangent
%     vectors as columns).
%     function n= ABC_normal(x,tangent)
%         n= cross(tangent(:,1),tangent(:,2));
%         n=n/norm(n);
%     end
function retobj = feblock_acoustics (varargin)
    class_name='feblock_acoustics';
    if (nargin == 0)
        parent = feblock;
        self.N= [];
        self.matstates= [];
        retobj = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options =varargin{1};
            parent = feblock(varargin{:});
            self.N= [];% 
            if isfield(options,'N')
                self.N = options.N;
            end
            self.matstates= [];
            retobj = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end
