% Compute the stiffness matrices of the individual gcells.
% Return an array of them so they may be assembled.
%    Call as
% ems = stiffness(feb, geom, u1, u)
%     geom=reference geometry field
%     u1=displacement field in the *current* configuration
%     u=displacement field in the last known configuration
%    Returns an array of elemat objects that may be assembled
%    into the system stiffness matrix.
%
function ems = stiffness (self, geom, u)
    gcells = get(self.feblock,'gcells');
    ngcells = count(gcells);
    nfens = get(gcells,'nfens');
    dim = get(geom,'dim');
    conns = get(gcells, 'conn'); % connectivity
    Kes= cell(ngcells,1);
    eqnums = cell(ngcells,1);
    for i=1:ngcells
        eqnums{i} =gather(u,conns(i,:),'eqnums');
        Ke=zeros(length(eqnums{i}));
        if (~isempty(self.translation_stiffness_matrix))
            Ke(1:3,1:3) = self.translation_stiffness_matrix{i};
        end
        if (~isempty(self.rotation_stiffness_matrix))
            Ke(4:6,4:6) = self.rotation_stiffness_matrix{i};
        end
        Kes{i} = Ke;
    end
    ems  = elematset(struct('mat',{Kes}, 'eqnums',{eqnums}));
end
