% Inspect the integration point quantities.
% by which the individual gcells act on the nodes.
% Return an array of elevec objects so they may be assembled.
% Input arguments
%     x        - reference geometry field
%     u        - displacement field
%     dT       - temperature difference field
%     output   - this is what you would assign to the output field all of
%                the context argument of the material update() method.
%     component- component of the output array: see the material update()
%                method.
% Output argument
%     fld - the new field that can be used to map values the colors
%
function fld = field_from_integration_points(self, geom, u, dT, output, component)
gcells = get(self.feblock,'gcells');
ngcells = length(gcells);
nfens = get(gcells(1),'nfens');
dim = get(geom,'dim');
% Make the inverse map from finite element nodes to geometric cells
f2gmap=fenode_to_gcell_map (struct ('gcells',gcells));
gmap=get (f2gmap,'gcell_map');
% The nodal data are initialized of the zero
nvals =0*(1:length(gmap))';
% Now loop over all gcells in the block
for i=1:length(gmap)
    inspector_data.component=component;
    inspector_data.sum_inv_dist=0;
    inspector_data.sum_quant_inv_dist=0;
    inspector_data.node_xyz=gather(geom,[i],'values','noreshape');
    inspector_data = inspect_integration_points(self, geom, u, dT, gmap{i}, struct ('output',output), ...
        @inspector, inspector_data);
    nvals(i)=inspector_data.sum_quant_inv_dist/inspector_data.sum_inv_dist;
end
fld=field(struct ('name', [output num2str(component)], 'data', nvals));
return;

function inspector_data=inspector(inspector_data, out, xyz)
d=inspector_data.node_xyz-xyz;
invd=1/norm(d);
inspector_data.sum_quant_inv_dist=inspector_data.sum_quant_inv_dist + invd*out(inspector_data.component);
inspector_data.sum_inv_dist=inspector_data.sum_inv_dist+invd;
return;

