% Compute the mass matrices of the individual gcells.
%
% function ems = mass (self, geom, u)
%
% Return an array of them so they may be assembled.
%   Call as:
%     ems = mass(feb, geom, u);
%   geom=geometry field
%   u=displacement field
%
function ems = mass (self, geom, u)
    gcells = get(self.feblock,'gcells');
    nfens = get(gcells(1),'nfens');
    dim = get(geom,'dim');
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    mat = get(self, 'mater');% Material
    rho = get(get(mat,'property'), 'rho');
    Nexp = zeros(dim,dim*nfens);
    % Now loop over all gcells in the block
    conns = get(gcells, 'conn'); % connectivity
    Me = cell(size(conns,1),1);
    eqnums = cell(size(conns,1),1);
    for i=1:size(conns,1)
        eqnums{i} =gather(u,conns(i,:),'eqnums');
        Me{i} =zeros(get(geom,'dim')*nfens);
    end
    xs =get(geom,'values');
    for j=1:npts_per_gcell
        N = bfun(gcells,pc(j,:));
        Nder = bfundpar(gcells,pc(j,:));
        for i=1:size(conns,1)
            conn =conns(i,:);
            x=xs(conn,:);
            J = Jacobian_matrix(gcells,Nder,x);
            Jac = Jacobian_volume(gcells,conn, N, J, x);
            for l = 1:nfens;
                Nexp(1:dim,(l-1)*dim+1:(l)*dim)=eye(dim)*N(l);
            end;
            Me{i} = Me{i} + (Nexp'*Nexp) * (rho * Jac * w(j));
        end
    end
    ems  = elematset(struct('mat',{Me}, 'eqnums',{eqnums}));
end
