% Set the material state of the individual integration points.
%
% function self = set_matstate (self, geom, u, State_function)
%
% Return  the block so that it can be saved with the changed material states.
%     geom=geometry field
%     u=displacement field
%     State_function = function handle
%      function matstate =State_function (mat,matstate,context);
function self = set_matstate (self, geom, u, State_function)
    gcells = get(self.feblock,'gcells');
    nfens = get(gcells,'nfens');
    % Integration rule
    integration_rule = get(self.feblock, 'integration_rule');
    pc = get(integration_rule, 'param_coords');
    w  = get(integration_rule, 'weights');
    npts_per_gcell = get(integration_rule, 'npts');
    for j=1:npts_per_gcell
        Ns{j} = bfun(gcells,pc(j,:));
        Nders{j} = bfundpar(gcells,pc(j,:));
    end
    % Material
    mat = get(self.feblock, 'mater');
    matstates =get(self,'matstates');
    % Now loop over all gcells in the block
    conns = get(gcells, 'conn'); % connectivity
    xs =gather(geom,(1:get(geom,'nfens')),'values','noreshape');
    for i=1:size(conns,1)
        conn =conns(i,:);
        x=xs(conn,:);
        U = gather(u,conn,'values');
        for j=1:npts_per_gcell
            c =Ns{j}'*x;
%             Rm = material_directions(self,gcells,pc(j,:),x);
            J = Jacobian_matrix(gcells,Nders{j},x);
            Jac = Jacobian_volume(gcells,conn, Ns{j}, J, x);
            Ndersp = Nders{j}/J;
            B = self.hBlmat(self,Ndersp,c,[]);%Rm(i,:,:));
            context.strain = B*U;
            context.xyz = c;
            context.gcell_id = i;
            matstates{i,j} =State_function(mat,matstates{i,j},context);
        end
    end
    self =set(self,'matstates',matstates);
end
