% C  PROCEDURE COMPUTES BEAM MASS MATRIX
% C
function MM=local_mass (self, A, I2, I3, IT, rho, L)
    if (self.mass_type == self.consistent_with_rotation_inertia)
        % C
        % C  CONSISTENT MASS MATRIX including ROTATIONAL MASSES
        MM =rho*A*L*[...
            1/3      0        0        0        0        0       1/6       0        0        0        0        0
            0     13/35       0        0        0    11*L/210     0      9/70       0        0        0    -13*L/420
            0        0     13/35       0    -11*L/210    0        0        0       9/70      0    13*L/420     0
            0        0        0     IT/3/A      0        0        0        0        0      IT/6/A     0        0
            0        0   -11*L/210     0     L^2/105     0        0        0    -13*L/420    0    -L^2/140     0
            0    11*L/210     0        0        0     L^2/105     0    13*L/420     0        0        0    -L^2/140
            1/6      0        0        0        0        0       1/3       0        0        0        0        0
            0      9/70       0        0        0     13*L/420    0      13/35      0        0        0   -11*L/210
            0        0       9/70    0     -13*L/420     0        0        0      13/35      0    11*L/210     0
            0        0        0     IT/6/A      0        0        0        0        0      IT/3/A     0        0
            0        0    13*L/420     0    -L^2/140     0        0        0     11*L/210     0     L^2/105    0
            0   -13*L/420     0        0        0    -L^2/140     0   -11*L/210     0         0        0    L^2/105];
        MM = MM+rho/L*[...
            0       0        0        0       0         0       0       0        0       0       0        0
            0    6/5*I2      0        0       0     L/10*I2     0    -6/5*I2     0       0       0    L/10*I2
            0       0     6/5*I3      0   -L/10*I3      0       0       0     -6/5*I3    0   -L/10*I3     0
            0       0        0        0       0         0       0       0        0       0       0        0
            0       0    -L/10*I3     0  2*L^2/15*I3    0       0       0     L/10*I3    0   -L^2/30*I3   0
            0    L/10*I2     0        0       0   2*L^2/15*I2   0    -L/10*I2    0       0       0    -L^2/30*I2
            0       0        0        0       0         0       0       0        0       0       0        0
            0   -6/5*I2      0        0       0     -L/10*I2    0    6/5*I2      0       0       0     -L/10*I2
            0       0     -6/5*I3     0    L/10*I3      0       0       0      6/5*I3    0    L/10*I3     0
            0       0        0        0       0         0       0       0        0       0       0        0
            0       0     -L/10*I3    0  -L^2/30*I3     0       0       0     L/10*I3    0   2*L^2/15*I3  0
            0   L/10*I2      0        0       0    -L^2/30*I2   0   -L/10*I2     0       0       0   2*L^2/15*I2];
    elseif (self.mass_type == self.consistent_no_rotation_inertia)
        % C
        % C  CONSISTENT MASS MATRIX excluding ROTATIONAL MASSES
        MM =rho*A*L*[...
            1/3      0        0        0        0        0       1/6       0        0        0        0        0
            0     13/35       0        0        0    11*L/210     0      9/70       0        0        0    -13*L/420
            0        0     13/35       0    -11*L/210    0        0        0       9/70      0    13*L/420     0
            0        0        0     IT/3/A      0        0        0        0        0      IT/6/A     0        0
            0        0   -11*L/210     0     L^2/105     0        0        0    -13*L/420    0    -L^2/140     0
            0    11*L/210     0        0        0     L^2/105     0    13*L/420     0        0        0    -L^2/140
            1/6      0        0        0        0        0       1/3       0        0        0        0        0
            0      9/70       0        0        0     13*L/420    0      13/35      0        0        0   -11*L/210
            0        0       9/70    0     -13*L/420     0        0        0      13/35      0    11*L/210     0
            0        0        0     IT/6/A      0        0        0        0        0      IT/3/A     0        0
            0        0    13*L/420     0    -L^2/140     0        0        0     11*L/210     0     L^2/105    0
            0   -13*L/420     0        0        0    -L^2/140     0   -11*L/210     0         0        0    L^2/105];
    elseif (self.mass_type == self.lumped_diagonal_with_rotation_inertia)
        % C
        % C  LUMPED DIAGONAL MASS MATRIX WITH ROTATIONAL MASSES
        % C
        HLM  = A*rho*L/2.;
        HLIT = rho*(I2 + I3)* L/2.;
        HLI2 = rho*I2* L/2.;
        HLI3 = rho*I3* L/2.;
        MM=zeros(12);
        CA = HLM;
        CB = HLIT;
        CC = HLI2;
        CD = HLI3;
        MM(1,1)     = MM(1,1)     + CA;
        MM(2,2)     = MM(2,2)     + CA;
        MM(3,3)     = MM(3,3)     + CA;
        MM(4,4)     = MM(4,4)     + CB;
        MM(5,5)     = MM(5,5)     + CC;
        MM(6,6)     = MM(6,6)     + CD;
        MM(7,7)     = MM(7,7)     + CA;
        MM(8,8)     = MM(8,8)     + CA;
        MM(9,9)     = MM(9,9)     + CA;
        MM(10,10)   = MM(10,10)   + CB;
        MM(11,11)   = MM(11,11)   + CC;
        MM(12,12)   = MM(12,12)   + CD;
    elseif (self.mass_type == self.lumped_diagonal_no_rotation_inertia)
        % C
        % C  LUMPED DIAGONAL ISOTROPIC MASS MATRIX WITHOUT ROTATIONAL MASSES
        % C
        HLM  = A*rho*L/2.;
        HLIT = rho*(I2 + I3)* L/2.;
        HLI2 = rho*I2* L/2.;
        HLI3 = rho*I3* L/2.;
        MM=zeros(12);
        CA = HLM;
        CB = 0.0;
        CC = 0.0;
        CD = 0.0;
        MM(1,1)     = MM(1,1)     + CA;
        MM(2,2)     = MM(2,2)     + CA;
        MM(3,3)     = MM(3,3)     + CA;
        MM(4,4)     = MM(4,4)     + CB;
        MM(5,5)     = MM(5,5)     + CC;
        MM(6,6)     = MM(6,6)     + CD;
        MM(7,7)     = MM(7,7)     + CA;
        MM(8,8)     = MM(8,8)     + CA;
        MM(9,9)     = MM(9,9)     + CA;
        MM(10,10)   = MM(10,10)   + CB;
        MM(11,11)   = MM(11,11)   + CC;
        MM(12,12)   = MM(12,12)   + CD;
    end
end