% Constructor of the finite element block class.
%    This class implements mechanics of small-strain deformation with arbitrarily large
%    deflections and rotations for two-node beam elements.
%
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options: those recognized by feblock
% and optionally
%      mass_type=
%          consistent_no_rotation_inertia=0;
%          consistent_with_rotation_inertia=1;
%          lumped_diagonal_no_rotation_inertia=2;
%          lumped_diagonal_with_rotation_inertia=3;
%      Rayleigh_damping_stiffness= stiffness-proportional damping parameter
%      Rayleigh_damping_mass=mass-proportional damping parameter
function retobj = feblock_defor_ss_corot_beam (varargin)
    class_name='feblock_defor_ss_corot_beam';
    if (nargin == 0)
        parent = feblock;
        self.consistent_no_rotation_inertia=0;
        self.consistent_with_rotation_inertia=1;
        self.lumped_diagonal_no_rotation_inertia=2;
        self.lumped_diagonal_with_rotation_inertia=3;
        self.mass_type= self.consistent_with_rotation_inertia;
        self.Rayleigh_damping_stiffness= 0;
        self.Rayleigh_damping_mass= 0;
        retobj = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            Parameters=varargin{1};
            parent = feblock(varargin{:});
            self.consistent_no_rotation_inertia=0;
            self.consistent_with_rotation_inertia=1;
            self.lumped_diagonal_no_rotation_inertia=2;
            self.lumped_diagonal_with_rotation_inertia=3;
            self.mass_type= self.consistent_with_rotation_inertia;
            if (isfield(Parameters,'mass_type'))
                self.mass_type=Parameters.mass_type;
                if (self.mass_type<0)||(self.mass_type>3)
                    error('Mass type not recognized');
                end
            end
            self.Rayleigh_damping_stiffness= 0;
            if (isfield(Parameters,'Rayleigh_damping_stiffness'))
                self.Rayleigh_damping_stiffness=Parameters.Rayleigh_damping_stiffness;
                if (self.Rayleigh_damping_stiffness<0)
                    error('Rayleigh_damping_stiffness negative');
                end
            end
            self.Rayleigh_damping_mass= 0;
            if (isfield(Parameters,'Rayleigh_damping_mass'))
                self.Rayleigh_damping_mass=Parameters.Rayleigh_damping_mass;
                if (self.Rayleigh_damping_mass<0)
                    error('Rayleigh_damping_mass negative');
                end
            end
            retobj = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
end
