% Compute the local Coriolis matrix for the inclusion of the element's
% spin about its own axis.
%
% function SM = local_coriolis(self,rho,A,I1,Omega,L) 
% 
% Inputs:
% rho= mass density, 
% A= cross-sectional area, 
% I1=mass moment of inertia of the cross-section about the x1 
% coordinate axis, 
% Omega= angular velocity,
% L= current length of the element, 
% 
% Outputs:
% SM = local Coriolis matrix, 12 x 12
% 
function SM = local_coriolis(self,rho,A,I1,Omega,L)
    %     %     Journal  of  Sound  and  Vibrarion    (1988)   125(3),   523-537
    %     % SPINNING      FINITE     ELEMENTS
    %     % A.  Y.  T.  LEUNG     AND    T.  C.  FUNG
    %     s11=[0,     0,    147;
    %          0,     0,     0;
    %        -147,    0,     0];
    %     s12=[0,   -21*L,     0;
    %          0,     0,     0;
    %          0,     0,     0]; s21=-s12';
    %     s13=[0,     0,    63;
    %          0,     0,     0;
    %        -63,    0,     0]; s31=-s13';
    %     s14=[0,   14*L,    0;
    %          0,     0,     0;
    %          0,     0,     0]; s41=-s14';
    %     s22=[0,     0,     0;
    %          0,     0,     0;
    %          0,     0,     0];
    %     s23=[0,     0,     0;
    %         14*L,   0,     0;
    %          0,     0,     0]; s32=-s23';
    %     s24=[0,     0,     0;
    %          0,     0,     0;
    %          0,     0,     0]; s42=-s24';
    %     s33=[0,     0,    147;
    %          0,     0,     0;
    %        -147,    0,     0];
    %     s34=[0,   21*L,     0;
    %          0,     0,     0;
    %          0,     0,     0]; s43=-s34';
    %     s44=[0,     0,     0;
    %          0,     0,     0;
    %          0,     0,     0];
    %     SM=rho*A*L/420*Omega*...
    %         [s11,s12,s13,s14;
    %         s21,s22,s23,s24;
    %         s31,s32,s33,s34;
    %         s41,s42,s43,s44;
    %         ];
    %from Dykstra's thesis
         s11=[0,     0,     0;
             0,     0,    6/5;
             0,   -6/5,    0];
        s12=[0,     0,     0;
             0,   -L/10,   0;
             0,     0,    -L/10]; s21=-s12';
        s13=[0,     0,     0;
             0,     0,   -6/5;
             0,    6/5,    0]; s31=-s13';
        s14=[0,     0,     0;
             0,   -L/10,   0;
             0,     0,    -L/10]; s41=-s14';
        s22=[0,     0,     0;
             0,     0, 2/15*L^2;
             0, -2/15*L^2, 0];
        s23=[0,     0,     0;
             0,   -L/10,   0;
             0,     0,    -L/10]; s32=-s23';
        s24=[0,     0,     0;
             0,     0, -1/30*L^2;
             0,  1/30*L^2, 0]; s42=-s24';
        s33=[0,     0,     0;
             0,     0,    6/5;
             0,   -6/5,    0];
        s34=[0,     0,     0;
             0,    L/10,   0;
             0,     0,    L/10]; s43=-s34';
        s44=[0,     0,     0;
             0,     0, 2/15*L^2;
             0, -2/15*L^2, 0];
        SM=Omega*rho*I1/L*[s11,s12,s13,s14;
            s21,s22,s23,s24;
            s31,s32,s33,s34;
            s41,s42,s43,s44;
            ];
end
