% Compute the element load vectors corresponding to nonzero essential boundary
% conditions (settlement of the supports).
% Return an array of them so they may be assembled.
%    Call as
% evs = nz_ebc_loads(feb, geom, u)
%     geom=geometry field
%     u=displacement field
%
function evs = nz_ebc_loads(self, geom, u)
    gcells = get(self.feblock,'gcells');
    dim = get(geom,'dim');
    % Material orientation /directions
    Rm = get(self,'Rm');
    eval_Rm = 0;
    if strcmp(class(Rm),'function_handle')
        eval_Rm = true; Rmh =Rm;
    end
    tangents =eye(dim);
    % Material
    mat = get(self.feblock, 'mater');
    D = tangent_moduli(mat,struct([]));
    [Princd,W]=eig(D);
    [ignore,ix]=sort(diag(W));
    Wmean=(W(ix(1),ix(1))+W(ix(2),ix(2)))/2;
    if Wmean<=0
        Wmean=max(diag(W));
    end
    %     Evaluate the nodal basis function gradients
    bfun_gradients = nodal_bfun_gradients (self, geom);
    %     Preallocate
    Fes= cell(length(bfun_gradients),1);
    eqnums = cell(length(bfun_gradients),1);
    for i=1:length(bfun_gradients)
        eqnums{i} =[];
        Fes{i} = [];
    end
    xs =gather(geom, 1:length(bfun_gradients), 'values', 'noreshape'); % coordinates of all nodes
    eqnumss =gather(u, 1:length(bfun_gradients), 'eqnums','noreshape');% equation numbers for all nodes
    % Now loop over all finite element nodes
    iem =1;
    for nix=1:length(bfun_gradients)
        if bfun_gradients{nix}.Vpatch>0 % This node has a element patch in this block
            pu = gather(u, bfun_gradients{nix}.patchconn, 'prescribed_values');
            if norm (pu) ~= 0
                np=length(bfun_gradients{nix}.patchconn);
                c = xs(nix, :); % coordinates of central node
                D = tangent_moduli (mat, struct ('xyz',c));% material tangent
                if (eval_Rm)% do I need to evaluate the local material orientation?
                    Rm =Rmh(c,tangents);%RAW: tangent vectors?
                end
                Bnodal= self.hBlmat (self,bfun_gradients{nix}.Nspd,c,Rm);
                Ke = Bnodal'*D*Bnodal * bfun_gradients{nix}.Vpatch;
                if (self.stabfact>0)
                    lx = xs(bfun_gradients{nix}.patchconn,:); % coordinates of nodes
                    Phi =self.hPhi(self,dim,np,lx,c);
                    A =Phi'*Phi;
                    try
                        A1 =Phi* ((Phi'*Phi)\Phi');
                        Kstab=self.stabfact*Wmean*(eye(size(Ke))-A1);
                        Ke = Ke + Kstab;
                    catch
                        warning
                    end
                end
                if (self.irrot_stabfact>0)
                    S=skewmat(zeros(dim,1));
                    Vrot = repmat(S, 1, (np)); % preallocate
                    for kK= 1:(np)
                        Vrot(:,(kK-1)*dim+1:kK*dim) =skewmat(bfun_gradients{nix}.Nspd(kK,:));
                    end
                    Kstab=self.irrot_stabfact*Vrot'*Vrot* bfun_gradients{nix}.Vpatch;
                    Ke = Ke + Kstab;
                end
                Fes{iem} =  -Ke*pu;
                eqnums{iem} =  reshape(eqnumss(bfun_gradients{nix}.patchconn,:)',(np)*size(eqnumss,2),1);
                iem=iem+1;
            end
        end
    end
    evs  = elevecset(struct('vec',{Fes(1:iem-1)}, 'eqnums',{eqnums(1:iem-1)}));
end
