
function Forces = contact_forces(self, geom0, u1, dchi)
    gcells = get(self.feblock,'gcells');
    ngcells = count(gcells);
    nfens = get(gcells,'nfens');
    dim = get(dchi,'dim');
    conns = get(gcells, 'conn'); % connectivity
    % Pre-allocate 
    Forces = cell(size(conns,1),1);
    Xs =gather(geom0,(1:get(geom0,'nfens')),'values','noreshape');
    U1s =gather(u1,(1:get(u1,'nfens')),'values','noreshape');
    X1s=Xs+U1s;
    % Are the reference points difference from the initial configuration?
    reference_equal_x0=isempty(self.reference_point);
    % Now loop over all gcells in the block
    for i=1:ngcells
        conn = conns(i,:); % connectivity
        x0 = Xs(conn,:); % initial coordinates of nodes
        x1 = X1s(conn,1:3); % current coordinates of nodes
        if (reference_equal_x0)
            xr=x0;
        else
            xr=self.reference_point(i,:);
        end
        dx=(x1- xr)-dot(self.direction(i,:),(x1- xr))*self.direction(i,:);
        distance=norm(dx);
        F1=zeros(3,1);
        if (distance > 0 )
            N=dx/distance;
            Fmag=self.force_function(conn,distance);
            F1=N*Fmag;% In global coordinates
        end
        Forces{i} = struct('nid',conn,'F',F1);
    end
end
