% Compute the proportional-damping matrices of the individual beam gcells.
% Return an array of them so they may be assembled.
%   
% function ems = damping_proportional(self, geom0, u1, Rfield1, dchi)
% 
%     geom0=initial geometry field; locations of nodes
%     u1=current geometry increment field; displacements of nodes
%     Rfield1=field of nodal frames, current deformation
%     dchi=field of translation and rotation increments
%             Equation numbers are taken from the field dchi.   
%
% The mass matrices are computed in the local coordinate system and
% then transformed into the global coordinate system.
%
function ems = damping_proportional(self, geom0, u1, dchi)
    ems={};
    if (self.Rayleigh_damping_stiffness~= 0)
        ems = stiffness(self, geom0, u1, dchi);
        mat=get(ems, 'mat');
        for i=1:length(mat)
            mat{i}=mat{i}*self.Rayleigh_damping_stiffness;
        end 
        ems=set(ems, 'mat',mat);
    end
end

