% Evaluate the manifold Jacobian.
%
% function Jac = Jacobian_mdim(self, conn, N, J, x, m)
%
%
%   For and m-dimensional cell, the manifold Jacobian is
%       m=0: +1
%       m=1: Jacobian_curve
%       m=2: Jacobian_surface
%       m=3: Jacobian_volume
%
%   where
%      self=gcellset,
%      conn=connectivity of a single cell in which the Jacobian is to be evaluated
%      N=values of the basis functions, size(N) = [nbfuns,1]
%      J = Jacobian matrix
%      x=array of spatial coordinates of the nodes, size(x) = [nbfuns,dim]
%
function Jac = Jacobian_mdim(self, conn, N, J, x, m)
    switch (m)
        case 3
            Jac = Jacobian_volume(self, conn, N, J, x);
        case 2
            Jac = Jacobian_surface(self, conn, N, J, x);
        otherwise
            error('Wrong dimension');
    end
end
