% Draw isosurface on a two-dimensional manifold gcell  (level curves, really).
%
% function   draw_isosurface(self, gv, context)
%
% Input arguments
% self = descendent of gcellset_2_manifold
% gv = graphic viewer
% context = struct
% with mandatory fields
%    x=reference geometry field
%    u=displacement field
% with optional fields
%    scalarfield =field with scalar vertex data,
%    isovalue = value of the isosurface
%    color = what color should the isosurface be?  Default: [1,1,1]/2;
%    edgealpha= transparency value
%    linewidth=line width (default 2) 
function   draw_isosurface(self, gv, context)
    conns = get(self, 'conn'); % connectivity
    [f,v]= isosurf_edges(self, [conns(:,[1,4,6]);conns(:,[4,2,5]);conns(:,[3,6,5]);conns(:,[4,5,6]);], context.x, context.u, context.scalarfield, context.isovalue);
    
    if (isfield(context,'color'))
        color =context.color;
    else
        color =[1,1,1]/2;
    end
    
    edgealpha = 1;
    if (isfield(context,'edgealpha'))
        edgealpha = context.edgealpha;
    end
    linewidth = 2;
    if (isfield(context,'linewidth'))
        linewidth = context.linewidth;
    end
    for j=1:size(f, 1 )
        patch('Faces',f(j,:),'Vertices',v,'FaceColor','none','EdgeColor',color,'linewidth',linewidth,'EdgeAlpha', edgealpha);
    end
end
