% Draw a graphic representation of data at the integration point.
%
% function draw (self, gv, context)
%
%
% Input arguments
% self = self
% gv = graphic viewer
% context = struct
%  with mandatory fields
%    xyz         - location at which the draw
%    ms          - material state
%    update_context     - context to be passed to the update () function.
%  with optional fields
%    quantity  - string: name of the quantity to display
%                 if quantity=='stress'
%                    the graphics representation is an ellipsoid of radii corresponding
%                    to the principal values of stress;
%                 otherwise
%                    the graphics representation is a sphere of radius corresponding
%                    to the value
%    component - index that says which component of the `quantity' quantity;
%                remember: the component points into the stress vector
%    data_cmap - data color map to use to color the quantity
%    es - transformation 3x3 matrix, with basis vectors in columns, that
%         describes the local Cartesian system for the material point
%
function draw (self, gv, context)
    quantity='stress';
    if (isfield(context,'quantity'))
        quantity= context.quantity;
    end
    scale = 1.0;
    if (isfield(context,'scale'))
        scale= context.scale;
    end
    switch (quantity)
        case 'stress'
            [sigmav,ignoreme] = update(self, context.ms, context.update_context);
            [V,D]=eig(stress_6v_to_3x3t(self,sigmav));
            component =1;
            if isfield(context,'component')
                component = context.component;
            end
            color =[1 1 0];
            if isfield(context,'data_cmap')
                color = map_data(context.data_cmap, sigmav(component));
            end
            context.facecolor= color;
            draw_ellipsoid(gv, context.xyz, V, scale*diag(D), context);
        case 'equiv_pl_def'
            context.update_context.output = quantity;
            [sigmav,ignoreme] = update(self, context.ms, context.update_context);
            color =[1 1 0];
            if isfield(context,'data_cmap')
                color = map_data(context.data_cmap, sigmav(1));
            end
            context.facecolor= color;
            draw_ellipsoid(gv, context.xyz, eye(3), scale*[1,1,1]*sigmav(1), context);
        otherwise
            %  do nothing;
    end
    return;
end
