% Get property from the specified object and return the value.
%   Call as:
%      get(obj), or
%      get(obj,prop_name)
%   where
%      obj       - object
%      prop_name - property name
%
%   The first form returns the list of property names as a string,
%   the second form returns the value of the named property.
%
function val = get(self,varargin)
    if (nargin == 1)
        val = {{{'bulk'}, {'Bulk modulus, scalar'}};...
            {{'eta'}, {'viscosity, scalar'}};...
            {{'alpha'}, {'coefficient of thermal expansion, scalar'}};...
            {{'alphas'}, {'coefficients of thermal expansion, array of three numbers'}};...
            };
        val = cat(1, val, get(self.property));
        return;
    else
        prop_name=varargin{1};
        switch prop_name
            case 'bulk'
                val = self.bulk;
            case 'eta'
                val = self.eta;
            case 'alpha'
                val = self.alpha;
            case 'alphas'
                val = self.alpha*ones(3, 1);
            case 'D'
                val = self.D;
            case 'D_visc'
                val = self.D_visc;
            otherwise
                val = get(self.property, prop_name);
        end
    end
end
