% Advance the state by specified number of steps
%   Call as:
%      advance(obj, torque, dt, nsteps)
%   where
%      obj       - object
%      torque    - handle to function defining spatial torque
%      dt        - time step
%      nsteps    - number of steps to take
%
%   The first form returns the list of property names as a string,
%   the second form returns the value of the named property.
%
function retobj = advance(self,torque,dt,nsteps)
    Omegan1 = self.Omega;
    Rn1 = self.R;
    t=get(self.rotint,'t');
    I=self.I;
    Ptol=100*eps;
    for i=1:nsteps
        Tn1=Rn1'*feval(torque, t, Rn1);
        Pin1=I*Omegan1;
        Pin=Pin1-dt*skewmat(Omegan1)*Pin1+dt*Tn1; % predictor
        i=0; maxi=50;
        while (1)
            pPin=Pin;
            Omegan=I\Pin;
            Rn=Rn1*rotmat(dt/2*Omegan1)*rotmat(dt/2*Omegan);
            Tn=Rn'*feval(torque, t+dt, Rn);
            Pin=Pin1-dt/2*skewmat(Omegan1)*Pin1+dt/2*Tn1-dt/2*skewmat(Omegan)*Pin+dt/2*Tn;
            i=i+1;
            if (i > maxi)
                if (max(abs(Pin-pPin)) > 1e-9)
                    warning(['trapez - Failed to converge: ||residual||=' num2str(norm(Pin))]);
                end
                break;
            end
            if (norm(Pin-pPin) < Ptol)
                break;
            end
        end
%         This is the conserved kinetic energy (at half step)
%         Omid = Omegan1 -dt/2*inv(I)*skewmat(Omegan1)*Pin1;
%         Omid'*I*Omid/2
        % swap variables for next step
        Rn1=Rn;
        Omegan1=I\Pin;
        t=t+dt;
    end
    self.R = Rn;
    self.Omega = Omegan;
    self.rotint = set(self.rotint,'t',t);
    retobj=self;
end

function Omegamid=slvimpl(I, t, dt, Rn1, Pin1, Tn1, torque, ceps)
    Omegamid=0*Pin1;
    i=0; maxi=50;
    while (1)
        pOmegamid=Omegamid;
        Rmid=Rn1*rotmat(dt/2*Omegamid);
        tmid=feval(torque, t+dt/2, Rmid);
        Omegamid=I\(Rmid'*(Rn1*Pin1+dt/2*tmid));
        i=i+1;
        if (norm(pOmegamid-Omegamid) < ceps)
            break;
        end
        if (i > maxi)
            if (norm(pOmegamid-Omegamid) > 1e-9)
                warning(['Failed to converge: ||residual||=' num2str(norm(pOmegamid-Omegamid))]);
            end
            break;
        end
    end
    return;
end

function Omegamid=approx_newton(I, t, dt, Rn1, Pin1, Tn1, torque, tol)
    Omegamid=I\Pin1;
    i=0; maxi=50;
    tmid=feval(torque, t+dt/2, Rn1*rotmat(dt/2*Omegamid));
    B=Pin1 + dt/2*Rn1'*tmid;
    res = Omegamid - I\(rotmat(-dt/2*Omegamid)*B);
    invIdt2 = inv(I) * dt^2/8;
    while (max(abs(res)) > tol)
        K = eye(3,3) - inv(I)*(dt/2*skewmat(B)) ...
            + invIdt2 * (skewmat(Omegamid)*skewmat(B) + skewmat(skewmat(Omegamid)*B));
        Omegamid = Omegamid - K\res;
        tmid=feval(torque, t+dt/2, Rn1*rotmat(dt/2*Omegamid));
        B=Pin1 + dt/2*Rn1'*tmid;
        res = Omegamid - I\(rotmat(-dt/2*Omegamid)*B);
        i=i+1;
        if (i > maxi)
            if (max(abs(res)) > 1e-9)
                warning(['Failed to converge: ||residual||=' num2str(norm(res))]);
            end
            break;
        end
    end
    return;
end