% The interior sphere accelerates in the positive x-direction, generating
% positive pressure ahead of it, negative pressure behind
function sphere_dipole_1
    rho=1.21e-3*1e-9;% mass density of air
    c =343*1000;% sound speed of air, millimeters per second
    bulk= c^2*rho;
    a_amplitude=1;% millimeters per second
    R=5;% length of the box, millimeters
    P_amplitude=R*rho*a_amplitude;% MPa
    Ro=4*R; % width of the box, millimeters
    tol=R/10000;
    nref=2;%
    nlayers=40;
    frequency=2000; % Hz
    omega=2*pi*frequency;
    graphics= true;% plot the solution as it is computed?
    
    [fens,gcells]=H8_sphere(R,nref);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [-1,0,0], [0,0,0], @(c)c([1, 4, 3, 2, 5, 8, 7, 6]));
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, tol);
    gcells=cat(gcells1,gcells2);
    
    bg=mesh_bdry(gcells);
    l=gcell_select(fens,bg,struct ('facing', true, 'direction', [0,1,1]));
    clear gcells
    % gv=drawmesh({fens,subset(bg,l)},'gcells','facecolor','white')
    % gv=drawmesh({fens,gcells1},'gcells','facecolor','white')
    [fens,gcells] = Q4_extrude(fens,subset(bg,l),nlayers,@(xyz, layer)(R+layer/nlayers*(Ro-R))*xyz/norm(xyz));
    connected = find_unconn_fens(fens, gcells);
    [fens, new_numbering] =compact_fens(fens, connected);
    gcells = renumber_gcell_conn(gcells, new_numbering);

    bg=mesh_bdry(gcells);
    clear options
    options. distance=R;
    options. inflate=tol;
    l1=gcell_select(fens, bg, options);
    clear options
    options. facing=true;
    options. direction=-[0,1,1];
    l2=gcell_select(fens, bg, options);
    sphere_gcells=subset(bg,intersect(l1,l2));
    
%     gv=drawmesh({fens,sphere_gcells},'gcells','facecolor','red')
    
    outerl=gcell_select(fens,bg,struct ('facing', true, 'direction', [0,1,1]));
    outer_gcells=subset(bg,outerl);
    
%     gv=drawmesh({fens,outer_gcells},'gv',gv,'gcells','facecolor','blue')
    
    prop=property_viscous_fluid(struct('bulk',bulk,'rho',rho));
    mater=mater_defor_ss_linviscel_triax (struct('property',prop));
    feb = feblock_acoustics (struct (...
        'mater',mater,'gcells',gcells,...
        'integration_rule',gauss_rule(3,2)));
    sfeb = feblock_acoustics (struct (...
        'mater',mater,'gcells',sphere_gcells,...
        'integration_rule',gauss_rule(2,2)));
    
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    P = field(struct ('name',['P'], 'dim', 1,'nfens',get(geom,'nfens')));
    outer_fenids=connected_nodes (outer_gcells);
    outer_prescribed=ones(1,length (outer_fenids));
    outer_comp=[];
    outer_val=0*outer_fenids;
    P = set_ebc(P, outer_fenids, outer_prescribed, outer_comp, outer_val);
    P = apply_ebc (P);
    P = numbereqns (P);
    
    C = start (sparse_sysmat, get(P, 'neqns'));
    C = assemble (C, acoustic_mass(feb, geom, P));
    
    function val=dipole_pressure_gradient(x)
        n=-x/norm(x);
        val=-rho*a_amplitude*n(1);
    end
    fi= force_intensity(struct('magn',@dipole_pressure_gradient));
    F = start (sysvec, get(P, 'neqns'));
    F = assemble (F, pressure_flux_loads (sfeb, geom, P, fi))
    
    P = scatter_sysvec(P, C\F);
    
    if ( graphics )
        bfeb = feblock(struct ('gcells',bg));
        gv=graphic_viewer;
        Camera = [-122.2098 -300.7925  102.5485   -0.1683    9.0280    7.0649         0         0    1.0000    2.9377];
        wv = get(P,'values');
        dcm=data_colormap(struct ('range',P_amplitude*[-1,1], 'colormap',bwr));
        colors=map_data(dcm, wv);
        colorfield = field(struct ('name',['cf'], 'dim', 3, 'data',colors));
        gv=reset (gv,[]);
        camset(gv,Camera);
        draw(bfeb,gv, struct ('x', geom,'u',0*geom,'colorfield',colorfield));
        draw_axes (gv,struct('length',R));
    end
end