kappa=[1.0 0; 0 1.0]; % W/m/K conductivity matrix
h=5;% W/m^2/K surface heat transfer coefficient
Q=100; % W/m^3 uniform heat source
b=3;% length of the equilateral triangle side in meters
Ta=5; % ambient temperature in degrees Celsius
num_integ_pts=1; % 1-point quadrature
fens = [fenodeset(struct('id',1:3','xyz',[[0,0];[b/2,0];[0,b/2*sin(30/180*pi)]]));...
    ];
gcells = [gcellset_T3(struct('id',1,'conn',[[1,2,3]],'other_dimension', 1))];
edge_gcells = [gcellset_L2(struct('id',1,'conn',[[1,2]],'other_dimension', 1))];
prop=property_diffusion(struct('conductivity',kappa,'source',Q));
mater=mater_diffusion (struct('property',prop));
feb = feblock_diffusion (struct ('mater',mater,...
    'gcells',gcells,...
    'integration_rule',tri_rule(num_integ_pts)));
edgefeb = feblock_diffusion (struct ('mater',mater,...
    'gcells',edge_gcells,...
    'integration_rule',gauss_rule(1,2),...
    'surface_transfer', h));
geom = field(struct('name',['geom'], 'dim', 2, 'fens',fens));
theta=field(struct('name',['theta'], 'dim', 1, 'nfens',...
    get(geom,'nfens')));
theta = numbereqns (theta);
amb = clone(theta, ['amb']);
fenids=[1,2];
prescribed=1;
comp=[];
val=Ta;
amb = set_ebc(amb, fenids, prescribed, comp, val);
amb = apply_ebc (amb);
K = start (sparse_sysmat, get(theta, 'neqns'));
K = assemble (K, conductivity(feb, geom, theta));
K = assemble (K, surface_transfer(edgefeb, geom, theta));
F = start (sysvec, get(theta, 'neqns'));
F = assemble (F, source_loads(feb, geom, theta));
F = assemble (F, surface_transfer_loads(edgefeb, geom, theta, amb));
theta = scatter_sysvec(theta, get(K,'mat')\get(F,'vec'));
% Plot
gv=graphic_viewer;
gv=reset (gv,[]);
T=get(theta,'values');
dcm=data_colormap(struct('range',[min(T),max(T)],'colormap',hot));
colorfield=field(struct ('name', ['colorfield'], 'data',...
    map_data(dcm, T)));
geomT=field(struct ('name', ['geomT'], ...
    'data',[get(geom,'values'), get(theta,'values')]));
draw(gcells, gv, struct ('x',geomT, 'u',0*geomT,...
    'colorfield',colorfield, 'shrink',0.9));
draw(gcells, gv, struct ('x',geom, 'u',0*geom, ...
    'facecolor','none'));
axis equal vis3d
zlabel('T')
% (get(theta,'values')-20)/(Q*a^2/6/kappa(1,1)) 
get(theta,'values')
set_graphics_defaults
assignin('caller','faesor_test_passed',(abs((35.387931034482754-somel(get(theta,'values'),3))<1e-12)))
