function t3nafems_ode
kappa=[35.0]; % conductivity matrix
cm = 440.5;% specific heat per unit mass
rho=7200;% mass density
cv =cm* rho;% specific heat per unit volume
Q=0; % uniform heat source
Tampl=100;
Tamb=0;
Tbar =@(t)(Tampl*sin(pi*t/40)+ Tamb);%hot face temperature
TRatebar =@(t)(pi/40*Tampl*cos(pi*t/40));%hot face temperature rate
num_integ_pts=2; % quadrature
L=0.1;% thickness
dt=0.5; % time step
tend= 64; % length of the time interval
t=0;
theta = 1.0; % generalized trapezoidal method
online_graphics= ~true;% plot the solution as it is computed?
n=3*5;% needs to be multiple of five
[fens,gcells] = L2_block(L,n,1.0); % Mesh
prop=property_diffusion(struct('conductivity',kappa,...
    'specific_heat',cv,'rho',rho,'source',Q));
mater=mater_diffusion (struct('property',prop));
feb = feblock_diffusion (struct (...
    'mater',mater,...
    'gcells',gcells,...
    'integration_rule',gauss_rule(1,num_integ_pts)));
geom = field(struct ('name',['geom'], 'dim', 1, 'fens',fens));
tempn = field(struct ('name',['temp'], 'dim', 1,...
    'nfens',get(geom,'nfens')));
tempn = set_ebc(tempn, 1, 1, 1, Tbar(t));
tempn = set_ebc(tempn, n+1, 1, 1, Tamb);
tempn = apply_ebc (tempn);
tempn = numbereqns (tempn);
tempn = scatter_sysvec(tempn,gather_sysvec(tempn)*0+Tamb);
K = start (dense_sysmat, get(tempn, 'neqns'));
K = assemble (K, conductivity(feb, geom, tempn));
Km = get(K,'mat');
C = start (dense_sysmat, get(tempn, 'neqns'));
C = assemble (C, capacity(feb, geom, tempn));
Cm = get(C,'mat');
tempn1=tempn;
function v=rhs(t,Tn1)
    tempn1 = scatter_sysvec(tempn1,Tn1);
    tempn1 = set_ebc(tempn1, 1, 1, 1, Tbar(t));
    tempn1 = set_ebc(tempn1, n+1, 1, 1, Tamb);
    tempn1 = apply_ebc (tempn1);
    F = start (sysvec, get(tempn, 'neqns'));
    F = assemble (F, nz_ebc_loads_conductivity(feb, geom, tempn1));
    tempn1 = set_ebc(tempn1, 1, 1, 1, TRatebar(t));
    tempn1 = set_ebc(tempn1, n+1, 1, 1, 0);
    tempn1 = apply_ebc (tempn1);
    F = assemble (F, nz_ebc_loads_capacity(feb, geom, tempn1));
    v = -Km*Tn1+get(F,'vec');
end
[ts,ys]=ode45(@rhs,[0, tend],gather_sysvec(tempn),odeset('Mass',Cm,'RelTol',1e-12));
    plot(ts,ys(:,n/5),'rx-','linewidth', 3)
set(gca,'FontSize', 14); grid on
xlabel('Time in seconds')
ylabel('Temperature in degrees Celsius')
end