function Perforated_strip
    graphics= ~~true;
    stabfact=0.1;
    L= 10; % Length of the plate
    W = 1; % Thickness of the plate
    H = 10; % Width
    R= 3;
    nL=8;nH=4;nR=4;
    magn=5;
    maxit = 15;
    nincr =1;
    utol = 0.1;
    
        lambda = 0.75e3;
        G= 14;

    nu =1/2*lambda/(G+lambda)
    E=G*(3*lambda+2*G)/(G+lambda);


    [fens,gcells]=elliphole(R,R,L,H,nL,nH,nR,[]);
    [fens,gcells] = extrudeq4(fens,gcells,1,@(x,i)([x,0]+[0,0,W*i]));
    [fens,gcells] = H8_to_H27(fens,gcells);

    prop = property_linel_iso (struct('E',E,'nu',nu));
    mater = mater_defor_neohook(struct('property',prop));
    feb = feblock_defor_nonlinear(struct ('mater',mater, 'gcells',gcells, ...
        'integration_rule',gauss_rule(3,3)));

    % Geometry
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    % Define the displacement field
    u   = clone(geom,'u');
    u   = u*0; % zero outfunction five
    % Apply EBC's
    ebc_fenids=fenode_select (fens,struct('box',[0,0,-Inf,Inf,-Inf,Inf],'inflate',1/1000));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ones(1,length (ebc_fenids))*1;
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    ebc_fenids=fenode_select (fens,struct('box',[-Inf,Inf,0,0,-Inf,Inf],'inflate',1/1000));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ones(1,length (ebc_fenids))*2;
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    ebc_fenids=fenode_select (fens,struct('box',[-Inf,Inf,-Inf,Inf,0,0],'inflate',1/1000));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=ones(1,length (ebc_fenids))*3;
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    u   = apply_ebc (u);
    % Number equations
    u   = numbereqns (u);
    % loaded boundary
    bdry_gcells = mesh_bdry(gcells, []);
    bcl = gcell_select(fens, bdry_gcells, ...
        struct ('box',[L,L,-Inf,Inf,-Inf,Inf],'inflate',H/1000));
    lfeb = feblock_defor_ss(struct ('mater',mater, 'gcells',bdry_gcells(bcl),...
        'integration_rule',gauss_rule(2,2)));

    gv=graphic_viewer;
    dt= 1/nincr;
 t=0; % time=load magnitude
   incr=1;
    while (incr <= nincr)
        t=t+ dt;
        disp(['Increment ' num2str(incr) ]); % pause
        % Initialization
        u1 = u; % guess
        du = 0*u; % this will hold displacement increment
        u1 = apply_ebc(u1);
        du = apply_ebc(du);
        K = start (sparse_sysmat, get(u, 'neqns'));

        iter=1;
        if graphics,
            gv=clear(gv,[]);
            gv=reset(gv,[]);
            axis off;
            draw(feb,gv, struct ('x', geom,'u',u, 'facecolor','cyan'));
            draw(feb,gv, struct ('x', geom,'u',0*u, 'facecolor','Yellow','alpha', 0.2));
%             camset(gv,cam);
            cam =camget(gv);
            %                  print(gcf, '-r50', [mfilename n2s0p(Frame) '.png'], '-dpng');
        end
        while 1
            feb1=feb;
            fi= force_intensity(struct ('magn',[t*magn;0; 0;]));
            F = start (sysvec, get(u, 'neqns'));
            F = assemble (F, distrib_loads(lfeb, geom, 0*u1, fi,2));
            [feb1,evs] = restoring_force(feb1,geom,u1,u);       % Internal forces
            F = assemble (F, evs);
            [febstab,evs] = restoring_force_stab(feb1,geom,u1,u,stabfact);       % Internal forces
            F = assemble (F, evs);
            ems=cat(2,stiffness(feb1, geom, u1,u),...
                stiffness_geo(feb1, geom, u1,u),...
                stiffness_stab(feb1, geom, u1,u,stabfact));
            K =assemble (K,ems);
            %             K = external_decomposition (K,  []);
            du = scatter_sysvec(du, K\F); % Displacement increment
            %                 max(abs(get(F,'vec')))
            u1 = u1 + du;   % increment displacement
            K = reinitialize (K);
            if graphics,
                draw(feb1,gv, struct ('x', geom,'u',u1, 'facecolor','none'));
                figure (gcf); pause(0.5); cam =camget(gv);
            end
            disp(['   It. ' num2str(iter) ': ||du||=' num2str(norm(du))]);
            if (max(abs(gather(du,[],'values'))) < utol) break; end;% convergence check
            if (iter >maxit)% bailout for failed convergence
                error( [' Possible failed convergence']);
            end
            iter=iter+1;
        end
        [feb,ignore] = restoring_force(feb,geom,u1,u);        % final update
        disp(['    Converged for t=' num2str(t)]); % pause
        u = u1;       % update the displacement
        incr = incr + 1;
    end
    if graphics,
        gv=reset(clear(gv,[]),[]);camset (gv,cam);
        draw(feb,gv, struct ('x', geom,'u',u, 'facecolor','red'));
        draw(feb,gv, struct ('x', geom,'u',0*u, 'facecolor','Yellow','alpha', 0.2));
    end
    %         camset(gv, [  -75.6602  613.9688  210.2074   20.6651   38.3517 20.5774         0         0    1.0000    5.3084]);
    clear K
end

