disp('Example UNIAXTENS: large strain uniaxial tension analysis');
% Parameters:
E=100;
nu=0.49992;
integration_order=2;
Fmag=3.81;
scale=1;
stressscale=scale/20;

% Mesh
fens = [  fenode(struct ('id',1,'xyz',[0 0 0])); ...
    fenode(struct ('id',2, 'xyz',[+1 0 0])); ...
    fenode(struct ('id',3, 'xyz',[+1 +1 0])); ...
    fenode(struct ('id',4, 'xyz',[0 +1 0])); ...
    fenode(struct ('id',5, 'xyz',[0 0 +1])); ...
    fenode(struct ('id',6, 'xyz',[+1 0 +1])); ...
    fenode(struct ('id',7, 'xyz',[+1 +1 +1])); ...
    fenode(struct ('id',8, 'xyz',[0 +1 +1])) ];
gcells = [ gcell_h8(struct ('id',1,'conn',[1 2 3 4 5 6 7 8])) ];
% Material% Finite element block
mater = mater_defor_neohook(struct('E',E,'nu',nu));
feb = feblock_defor_nonlinear (struct ('mater',mater, 'gcells',gcells, 'integration_order',integration_order));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
% Define the displacement field
u   = 0*geom; % zero out
% Apply EBC's
u   = set_ebc(u, [1 1 1], [1 1 1], [1 2 3], [0 0 0]);
u   = apply_ebc (u);
u   = set_ebc(u, [2 2], [1 1], [2 3], [0 0]);
u   = apply_ebc (u);
u   = set_ebc(u, [3], [1], [3], [0]);
u   = apply_ebc (u);
u   = set_ebc(u, [4 4], [1 1], [1 3], [0 0]);
u   = apply_ebc (u);
u   = set_ebc(u, [5 5], [1 1], [1 2], [0 0]);
u   = apply_ebc (u);
u   = set_ebc(u, [6], [1], [2], [0]);
u   = apply_ebc (u);
u   = set_ebc(u, [8], [1], [1], [0]);
u   = apply_ebc (u);
% Number equations
u   = numbereqns (u);

% Now comes the nonlinear solution
tup = 1;
tlo = -1;
nincr = 10;
u = u*0; % zero out the displacement
utol = 10e-12;
Fs=[];
us=[];
t=tlo; % time=load magnitude
incr=1;
gv=graphic_viewer;
    while (incr <= nincr+1)
    % Initialization
    u1 = u; % guess
    u1 = apply_ebc(u1);
    du = 0*u; % this will eachhold displacement increment
    du = apply_ebc(du);
    iter=1;
    gv=reset(clear(gv,[]),[]);
    draw(feb,gv, struct ('x', geom,'u',u, 'facecolor','red'));
    while 1
        feb1=feb;                                           % Make a copy of the state
        F = start (sysvec, get(u, 'neqns'));          % Assemble loads: beam bending
        for i = [5 6 7 8]
            F = assemble (F, loads(nodal_load(struct ('id',i,'dir',[3],'magn',[Fmag*t])), u));
        end
        [ignore,evs] = restoring_force(feb1,geom,u1,u);       % Internal forces
        F = assemble (F, evs);
        F = finish(F);
        K = start (dense_sysmat, get(u, 'neqns'));
        K = assemble (K, stiffness(feb1, geom, u1,u));
        K = assemble (K, stiffness_geo(feb1, geom, u1,u));
        K = finish (K);
        % Displacement increment
        x = get(K,'mat') \ get(F,'vec');;
        du = scatter_sysvec(du, x);
        u1 = u1 + du;                                       % increment displacement
        draw(feb1,gv, struct ('x', geom,'u',u1, 'facecolor','none'));
        disp(['   Iteration ' num2str(iter) ': ||du||=' num2str(norm(du))]);
        if (norm(du) < utol) break; end;                    % convergence check
        pause(0.02);        
        iter=iter+1;
        if iter > 20
            error ('divergence')
        end
    end
    [feb,ignore] = restoring_force(feb,geom,u1,u);        % final update
    gv=reset (gv,[]);
    draw(feb,gv, struct ('x', geom,'u',u1, 'facecolor','red'));
    disp(['Increment ' num2str(incr) ': Converged for t=' num2str(t) ':  hit return']); % pause
    u = u1;                                               % update the displacement
    u7=gather(u,[7],'values');
    us=[us u7(3)]
    Fs=[Fs Fmag*t];
    t = t + (tup-tlo) / nincr;
    incr = incr + 1;
end

plot(us,Fs)