% Buckling of a clamped box at the bottom loaded uniformly other top.
% Reference solution from ABAQUS 38.366,30.821,30.824,23.489
% with about 45,000 degrees of freedom
function Box_buckling_27
    disp('Example: linear box buckling analysis');
    % Parameters:
    E=210e9;
    nu=0.3;
    Thickness= 0.1; iDim = 10/2-Thickness/2; eDim = iDim +Thickness; Length= iDim+eDim;
    
    nD= 2;nt=1;nL=2*nD;
    %   nD= 4;nt=1;nL=2*nD;
%     nD= 6;nt=1;nL=2*nD;
%     nD= 8;nt=1;nL=2*nD;
    
    D=E*Thickness^3/12/(1-nu^2);
    magn=D/Thickness/(iDim+eDim)^2;
    scale=5000;
    neigvs = 4;
    uscale=20000;
    Reference= [23.489,30.821,30.824,38.366,];
    
    % Mesh
    
    % [fens,gcells]=block(rA, Thickness, Length, nc,nt,na);
    [fens,gcells] = Q4_quadrilateral([iDim,0;eDim,0;eDim,eDim;iDim,iDim],nt,nD,[]);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [-1,1], [0,0]);
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, Thickness/1000);
    gcells=cat(gcells1,gcells2);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [0,1], [0,0]);
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, Thickness/1000);
    gcells=cat(gcells1,gcells2);
    [fens1,gcells1] = mirror_mesh(fens, gcells, [1,0], [0,0]);
    [fens,gcells1,gcells2] = merge_meshes(fens1, gcells1, fens, gcells, Thickness/1000);
    gcells=cat(gcells1,gcells2);
    function xyz= up(xyz, layer)
        xyz= [xyz, +(layer/nL)*Length];
    end
    [fens,gcells] = Q4_extrude(fens,gcells,nL,@up);
    [fens,gcells] = H8_to_H27(fens,gcells);
    
    % drawmesh({fens,gcells},'gcells')
    % Material
    prop = property_linel_iso(struct('E',E,'nu',nu));
    mater = mater_defor_ss_linel_triax(struct('property',prop));
    % Finite element block
    feb = feblock_defor_ss_nonlinear (struct ('mater',mater, 'gcells',gcells,...
        'integration_rule',gauss_rule(3,3)));
    % Geometry
    geom = field(struct ('name',['geom'], 'dim', 3, 'fens',fens));
    % Define the displacement field
    u   = 0*geom; % zero out
    
    % Apply EBC's
    ebc_fenids=fenode_select (fens,struct('box',[-Inf,Inf,-Inf,Inf,0,0,],'inflate',Thickness/1000));
    ebc_prescribed=ones(1,length (ebc_fenids));
    ebc_comp=[];
    ebc_val=ebc_fenids*0;
    u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
    u   = apply_ebc (u);
    % Number equations
    u   = numbereqns (u);
    disp([num2str(get(u, 'neqns')) ' degrees of freedom'])
    % Assemble the system matrix
    ems = stiffness(feb, geom, u, u);
    K = start (sparse_sysmat, get(u, 'neqns'));
    K = assemble (K, ems);
    
    % Load
    bdry_gcells = mesh_bdry(gcells, []);
    bcl = gcell_select(fens, bdry_gcells, ...
        struct ('box',[-Inf,Inf,-Inf,Inf,Length,Length],'inflate',Thickness/1000));
    lfeb = feblock_defor_ss(struct ('mater',mater, 'gcells',subset(bdry_gcells,bcl),...
        'integration_rule',gauss_rule(2,2)));
    fi= force_intensity(struct ('magn',[0;0;-magn; ]));
    F = start (sysvec, get(u, 'neqns'));
    F = assemble (F, distrib_loads(lfeb, geom, u, fi,2));
    % Solve
    u = scatter_sysvec(u, K\F);
    
    
    ulin = u; %  linear displacement solution
    gv=graphic_viewer;
    cmap = cadcolors2;
    gv=reset(clear(gv,[]),[]);
    fld = field_from_integration_points(feb, geom, u, [], 'Cauchy', 3);
    nvals=get(fld,'values'); %[min(nvals),max(nvals)]
    dcm=data_colormap(struct ('range', [min(nvals),max(nvals)], 'colormap',jet));
    colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvals)));
    draw(feb, gv, struct ('x',geom,'u', uscale*u, 'colorfield',colorfield, 'shrink',1));
    
%     dcm=data_colormap(struct ('range', [min(nvals),max(nvals)], 'colormap',jet));
%     % Derived from element displacements
%     for i=1:count(gcells)
%         feb1 = feblock_defor_ss (struct('mater',mater,'gcells',subset(gcells,i),...
%             'integration_rule',gauss_rule(3, 2)));
%         fld = field_from_integration_points(feb1, geom, u, [], 'Cauchy', 3);
%         nv=get(fld,'values');
%         ix=find(nv~=0);
%         nv(ix)=mean(nv(ix));
%         colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nv)));
%         draw(feb1, gv, struct ('x',geom,'u', uscale*u, 'colorfield',colorfield, 'shrink',1));
%     end
%         
draw_colorbar(gv, struct('colormap',cmap,'position',[0.85 0.15 0.05 0.7],...
                'minmax',get(dcm, 'minmax'),'label',['\sigma_{z}']));
    pause(0.01); % next eigenvector
    
    
    
    disp('Stability analysis');
    [feb1,evs] = restoring_force(feb,geom,ulin,0*ulin);       % Internal forces
    ems = stiffness_geo(feb1, geom, ulin, ulin);            % Geometric stiffness
    K_geo = start (sparse_sysmat, get(u, 'neqns'));
    K_geo = assemble (K_geo, ems);
    
    options.tol =1e-26;
    options.maxit = 5000;
    options.disp = 0;
    [W,Omega]=eigs(-(get(K_geo,'mat')+get(K_geo,'mat')')/2,(get(K,'mat')+get(K,'mat')')/2,...
        neigvs,'lm', options);
    Omegas=(1./(diag(Omega)));
   
    
    gv=graphic_viewer;
    cmap = cadcolors2;
    w=clone(ulin,'w');
    for i=neigvs:-1:1
        disp(['  Eigenvector ' num2str(i) ' eigenvalue ' num2str(Omegas(i)) ', error ' num2str(abs((Omegas(i)-Reference(i))/Reference(i)*100)) '%']);
        gv=reset(clear(gv,[]),[]);
        
        w = scatter_sysvec(w, W(:,i));
        v = get(w,'values');
        wmag = field(struct ('name',['wmag'], 'dim', 1, 'nfens',count(fens)));
        wmag = scatter(wmag,1:get(wmag,'nfens'),sqrt(v(:,1).^2+v(:,2).^2+v(:,3).^2));
        nvals =gather(wmag,1:get(wmag,'nfens'),'values');
        nvalsrange=[min(nvals),max(nvals)];
        dcm=data_colormap(struct ('range',nvalsrange, 'colormap',cmap));
        colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvals)));
        draw(feb,gv, struct ('x', geom, 'u', scale*w,'colorfield',colorfield, 'shrink',1.0));
        
        pause(1); % next eigenvector
    end
    assignin('caller','faesor_test_passed',(norm(Omegas(1)-26.038696877297280)<1e-3));
end
