disp('Taut wire: example 1-- statics, uniform load');
L=6;% length of span
P=4;% prestressed force
q =0.1;% distributed load, consistent with the sign convention in the textbook
n=2; % number of elements
% Mesh
% finite element node set
fens=fenodeset(struct ('id',(1:n+1)','xyz',linspace(0, L, n+1)'));
% set of geometric cells
gcells = gcellset_L2(struct('id',1,'conn',[(1:n)', (2:n+1)']));
% Finite element block
feb = feblock_defor_taut_wire(struct ('mater',mater,...
    'gcells',gcells,...
    'integration_rule',simpson_1_3_rule,...
    'P',P));
% Geometry
geom = field(struct ('name',['geom'], 'dim', 1, 'fens',fens));
% Define the displacement field
w   = 0*clone(geom,'w');
% Apply EBC's
fenids=[1]; prescribed=[true]; component=[1]; val=0;
w   = set_ebc(w, fenids, prescribed, component, val);
w   = apply_ebc (w);
% Number equations
w   = numbereqns (w);
% Assemble the system matrix
K = start (dense_sysmat, get(w, 'neqns'));
K = assemble (K, stiffness(feb, geom, w));
% Load
fi = force_intensity(struct ('magn',q));
F = start (sysvec, get(w, 'neqns'));
F = assemble (F, body_loads(feb, geom, w, fi));
% Solve
w = scatter_sysvec(w, get(K,'mat')\get(F,'vec'));
% Plot
xs= (0:0.01:L);
plot (xs, -q/P*xs.*(xs/2-L),'r-','linewidth', 3); 
hold on
plot (gather(geom, (1:n+1),'values'), ...
    gather(w, (1:n+1),'values'),'bo-','linewidth', 3); 
left_handed_axes;% Plotting is consistent with the textbook sign convention
xlabel('x'),ylabel('w')
assignin('caller','faesor_test_passed',((norm([     0;    0.3375;     0.4500]-gather(w, (1:n+1),'values')))<1e-12));