
% Parameters:
Ea=70e9;
nua=0.33;
alphaa= 23e-6;
Es=200e9;
nus=0.3;
alphas= 12e-6;
thickness = 5.0;
nip =3;
scale=10;
edgecolor='none';
edgecolor='black';
cmpn=1;cmpnlabel='\sigma_{rr}';
cmpn=2;cmpnlabel='\sigma_{zz}';
cmpn=3;cmpnlabel='\sigma_{\theta\theta}';
% cmpn=4;cmpnlabel='\sigma_{rz}';

h=8*1.25;
ThicknessF= 4;
ThicknessD= 10;
RadiusF= 25;
RadiusD= 50;
[fens,gcells,groups,edge_gcells,edge_groups]=targe2_mesher({...
    ['curve 1 line ' num2str(0) ' ' num2str(0) ' ' num2str(RadiusF) ' ' num2str(0) ' '],...
    ['curve 2 line ' num2str(RadiusF) ' ' num2str(0) ' ' num2str(RadiusD) ' ' num2str(0) ' '],...
    ['curve 3 line ' num2str(RadiusD) ' ' num2str(0) ' ' num2str(RadiusD) ' ' num2str(ThicknessD) ' '],...
    ['curve 4 line ' num2str(RadiusD) ' ' num2str(ThicknessD) ' ' num2str(RadiusF) ' ' num2str(ThicknessD) ' '],...
    ['curve 5 line ' num2str(RadiusF) ' ' num2str(ThicknessD) ' ' num2str(0) ' ' num2str(ThicknessD) ' '],...
    ['curve 6 line ' num2str(0) ' ' num2str(ThicknessD) ' ' num2str(0) ' ' num2str(ThicknessD-ThicknessF) ' '],...
   ['curve 7 line ' num2str(0) ' ' num2str(ThicknessD-ThicknessF) ' ' num2str(0) ' ' num2str(0) ' '],...
   ['curve 8 line ' num2str(RadiusF) ' ' num2str(0) ' ' num2str(RadiusF) ' ' num2str(ThicknessD-ThicknessF) ' '],...
   ['curve 9 line ' num2str(RadiusF) ' ' num2str(ThicknessD-ThicknessF) ' ' num2str(RadiusF) ' ' num2str(ThicknessD) ' '],...
   ['curve 10 line ' num2str(RadiusF) ' ' num2str(ThicknessD-ThicknessF) ' ' num2str(0) ' ' num2str(ThicknessD-ThicknessF) ' '],...
    ['subregion 1  property 1 boundary  1 2 3 4 -9 -8 8 10 7'],...
    ['subregion 2  property 2 boundary -10 9 5 6'],...
    ['m-ctl-point constant ' num2str(h)],...
    ['m-ctl-point 1 xy ' num2str(RadiusF)  ' ' num2str(ThicknessD-ThicknessF) ' near ' num2str(h/1e4)...
    ' influence  ' num2str(h/1e3)],...
   ['m-ctl-point 1 xy ' num2str(RadiusF)  ' ' num2str(ThicknessD) ' near ' num2str(h/1e4)...
    ' influence  ' num2str(h/1e3)]
    }, thickness, struct('axisymm',true,'quadratic',true));
% Material
propa = property_linel_iso ...
    (struct('E',Ea,'nu',nua,'alpha', alphaa));
matera = mater_defor_ss_linel_biax (struct('property',propa, ...
    'reduction','axisymm'));
props = property_linel_iso ...
    (struct('E',Es,'nu',nus,'alpha', alphas));
maters = mater_defor_ss_linel_biax (struct('property',props, ...
    'reduction','axisymm'));
% Finite element block
feba = feblock_defor_ss (struct ('mater',matera,...
    'gcells',subset(gcells,groups{2}),...
    'integration_rule',tri_rule (nip)));
febs = feblock_defor_ss (struct ('mater',maters,...
    'gcells',subset(gcells,groups{1}),...
    'integration_rule',tri_rule (nip)));
geom = field(struct ('name',['geom'], 'dim', 2, 'fens',fens));
u   = clone(geom,'u');
u   = u*0; % zero out
% Apply EBC's
ebc_fenids=fenode_select (fens,struct('box',[0 0 0 ThicknessD],'inflate', 0.01));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=1*ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
ebc_fenids=fenode_select (fens,struct('box',[0 0 0 0],'inflate', 0.01));
ebc_prescribed=ones(1,length (ebc_fenids));
ebc_comp=2*ones(1,length (ebc_fenids));
ebc_val=ebc_fenids*0;
u   = set_ebc(u, ebc_fenids, ebc_prescribed, ebc_comp, ebc_val);
u   = apply_ebc (u);
u   = numbereqns (u);
% Temperature field
dT = field(struct ('name',['dT'], 'dim', 1, ...
    'data',zeros(count(fens),1)-70));
% Assemble the system matrix
K = start (sparse_sysmat, get(u, 'neqns'));
K = assemble (K, cat(2,stiffness(febs, geom, u),stiffness(feba, geom, u)));
% Load
F = start (sysvec, get(u, 'neqns'));
F = assemble (F, cat(2,thermal_strain_loads(febs, geom, u, dT),thermal_strain_loads(feba, geom, u, dT)));
% Solve
u = scatter_sysvec(u, get(K,'mat')\get(F,'vec'));
% get(u,'values')

% Plot
gv=graphic_viewer;
gv=reset (gv,struct ('limits',[0 1.26*RadiusD  0 1.5*ThicknessD]));
cmap = jet;
set(gca,'FontSize', 12)
flda = field_from_integration_points(feba, geom, u, dT, 'Cauchy', cmpn);
flds = field_from_integration_points(febs, geom, u, dT, 'Cauchy', cmpn);
nvalsa=get(flda,'values');
nvalss=get(flds,'values');
nvalmin =min(min(nvalsa),min(nvalss));
nvalmax =max(max(nvalsa),max(nvalss))
dcm=data_colormap(struct ('range',[-nvalmax,nvalmax], 'colormap',cmap));
geom3=field(struct ('name', ['geom3'], ...
    'data',[get(geom,'values'),3e-8*nvalsa]));
u3=field(struct ('name', ['u3'], ...
    'data',[scale*get(u,'values'),0*nvalsa]));
colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvalsa)));
draw(feba, gv, struct ('x',geom3,'u', scale*u3, 'colorfield',colorfield, 'shrink',1,'edgecolor',edgecolor));
% draw(feba, gv, struct ('x',geom,'u', 0*u, 'facecolor',' none'));
geom3=field(struct ('name', ['geom3'], ...
    'data',[get(geom,'values'),3e-8*nvalss]));
u3=field(struct ('name', ['u3'], ...
    'data',[scale*get(u,'values'),0*nvalss]));
colorfield=field(struct ('name', ['colorfield'], 'data',map_data(dcm, nvalss)));
draw(febs, gv, struct ('x',geom3,'u', scale*u3, 'colorfield',colorfield, 'shrink',1,'edgecolor',edgecolor));
% draw(febs, gv, struct ('x',geom,'u', 0*u, 'facecolor',' none'));
lighting  none;
title (['h=' num2str(h)]);
colormap(cmap);
draw_colorbar(gv,struct('position',[0.72 0.33 0.05 0.5],...
    'minmax',[-nvalmax,nvalmax],'label',cmpnlabel));
view (2)
%  saveas(gcf, [mfilename '-' num2str(h) '.png'], 'png');
    
