% Create a solid mesh of 1/8 of the sphere of "radius". 
%
% function [fens,gcells]=H8_sphere(radius,nrefine)
%
% Create a mesh of 1/8 of the sphere of "radius". The  mesh will consist of
% four hexahedral elements if "nrefine==0", or more if "nrefine>0".
% "nrefine" is the number of bisections applied  to refine the mesh.
% 
function [fens,gcells]=H8_sphere(radius,nrefine)
    a=sqrt(2)/2;
    b=1/sqrt(3);
    c=0.6*a;
    d=0.6*b;
    xyz= [0,0,0;
        0.5,0,0;
        c,c,0;
        0,0.5,0;
        0,0,0.5;
        c,0,c;
        d,d,d;
        0,c,c;
        0,0,1;
        a,0,a;
        1,0,0;
        a,a,0;
        0,1,0;
        0,a,a;
        b,b,b]*radius;
    conn=[1,2,3,4,5,6,7,8;
        2,11,12,3,6,10,15,7;
        4,3,12,13,8,7,15,14;
        5,6,7,8,9,10,15,14];
    fens =fenodeset(struct('id',(1:15)','xyz',xyz));
    gcells=gcellset_H8(struct ('id', (1:4)','conn',conn));
    for i=1:nrefine
        [fens,gcells]=H8_refine(fens,gcells);
        bg=mesh_bdry(gcells);
        l=gcell_select(fens,bg,struct ('facing', true, 'direction', [1,1,1]));
        cn = connected_nodes(subset(bg,l))   ;
        xyz=get(fens,'xyz');
        for j=1:length(cn)
            xyz(cn(j),:)=xyz(cn(j),:)*radius/norm(xyz(cn(j),:));
        end
        fens=set(fens,'xyz',xyz);
    end
end
