%  Validate finite element mesh.
%
% function validate_mesh(fens, gcells)
%
% A finite element mesh to them by the node array And the geometric cell
% array Is validated by checking the sanity of the numbering:
% -- the node numbers need to be positive and in serial order
% -- the gcell connectivity needs to refer to valid nodes
% 
% An error is reported as soon as it is detected.
% 
function validate_mesh(fens, gcells)
    nfens=count(fens);
    id1 = get(fens,'id');
    if (sum(abs(id1-reshape(1:nfens,size(id1,1),size(id1,2))))~=0)
        error ('Wrong node numbers: Nodes need to be numbered in serial order')
    end
    if (sum(abs(id1-abs(id1)))~=0)
        error ('Wrong node numbers: Node numbers need to be positive')
    end
    
    conn=get(gcells,'conn');
    
%     sconn =sort (conn,2);
%     uconn =unique(sconn,'rows');
%     if (size(conn,1)~=size(uconn,1))
%         error (['Repeated connectivity: ' num2str(size(uconn,1)) ' of ' num2str(size(conn,1)) ' unique'])
%     end
    
    for i=1:size(conn,1)
        if (max(conn(i,:))>nfens)
            error (['Wrong connectivity (refers to nonexistent node) ' num2str(conn(i,:))])
        end
        if (min(conn(i,:))<1)
            error (['Wrong connectivity (refers to nonexistent node) ' num2str(conn(i,:))])
        end
        if (length(unique(conn(i,:)))~=length(conn(i,:)))
            error (['Wrong connectivity (multiply referenced node) ' num2str(conn(i,:))])
        end
    end
end
